<!DOCTYPE html>
{% load i18n %}
<html ng-app="MyApp">
<head>

    <script src="//ajax.googleapis.com/ajax/libs/angularjs/1.2.13/angular.min.js"></script>
    <script src="//ajax.googleapis.com/ajax/libs/angularjs/1.2.13/angular-route.js"></script>
    <script>
         angular.module('app', ['ngRoute']);
    </script>
    <title>{% trans "BI Angular Test" %}</title>
</head>
<body >
<h1>{% trans "Hello World." %} {$  1 + 2 $}</h1>
</body>
</html>
