{% extends "base_status.html" %}
{% load url from future %}
{% load i18n %}

{% block title %}List of Hosts{% endblock %}
{% block smallheader %}list{% endblock %}
{% block largeheader %}Hosts{% endblock %}

{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url "contrib.views.index" %}">{% trans "contrib" %}</a>{% endblock %}

{% load adagiostags %}


{% block content %}
<ul>
    {% for i in hosts %}
        <li><a href="./{{ i.name }}/">{{ i.name }}</a></li>
    {% endfor %}
</ul>
{% endblock %}

