{% extends "base.html" %}
{% load i18n %}

{% block title %}{{ block.super }}{% endblock title %}

{% block top_navigation %}{{ block.super }}{% endblock top_navigation %}
{% block page_header %}{{ block.super }}{% endblock page_header %}



{% block header %}{{ block.super }}{% endblock header %}
{% block footer %}{{ block.super }}{% endblock footer %}

{% block nav1 %}{{ block.super }}{% endblock nav1 %}
{% block nav2 %}{{ block.super }}{% endblock nav2 %}

{% block smallheader %}{{ block.super }}{% endblock smallheader %}
{% block largeheader %}{{ block.super }}{% endblock largeheader %}


<!-- Main contents go in here -->
{% block content %}
    <p>
    {% trans "Stuff the main content of your view in here. Your main content should go in here." %}
    </p>
{% endblock content %}

{% block toolbar %}<div class="alert alert-info">{% trans "Toolbar goes here" %}</div>{% endblock toolbar %}
