{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Hosts" %}{% endblock %}
{% block nav2 %}
    <a href="{% url 'status.views.hosts' %}">{% trans "Hosts" %}</a>
    {% if host_name %}
    / {{ host_name }}
    {% else %}
    {% endif %}
{% endblock %}
{% block smallheader %}
    {% if hostgroup_name %}host
    {% endif %}
{% endblock %}
{% block largeheader %}
    {% if host_name %}{{ host_name }}
    {% else %}
    {% trans "Hosts" %}
    {% endif %}
{% endblock %}

{% block content %}
    {% include "snippets/status_hostlist_snippet.html" %}
{% endblock %}

{% block header %} {{ block.super }}
{% endblock %}


