{% extends "base.html" %}

{% load i18n %}

{% block title %}{% trans "Copy Object" %}{% endblock %}
{% block smallheader %}{% trans "Copy" %}{% endblock %}
{% block largeheader %}{{ object.object_type }}{% endblock %}
{% block nav1 %}<a href="{% url "objectbrowser" %}">{% trans "Object Browser" %}</a>{% endblock %}
{% block toolbar %}{% endblock %}


{% block content %}
    {% if success %}
        {% for i in copied_objects %}
            <div class="alert alert-success">
                <button class="close" data-dismiss="alert">×</button>
                <strong>{% trans "Success!" %}</strong>
		{% url "edit_object" i.id as the_url %}
                {% blocktrans with type=i.object_type desc=i.description file=i.filename %}
		{{ type }} <a href="{{ the_url }}">"{{ desc }}"</a> was successfully saved to {{ file }}.
		{% endblocktrans %}
            </div>
        {% endfor %}
    {% else %}
        <div class="alert alert-info">
            {% blocktrans with type=object.object_type desc=object.description %}
                You are about to copy {{ type }} "{{ desc }}".
            {% endblocktrans %}
        </div>
        <p></p>
        <form  action="#" method="POST" class="form-horizontal">{% csrf_token %}
            {% include "bootstrap_fields.html" with fields=form %}
            <button class="btn btn-success" type="submit"><i class=" icon-thumbs-up icon-white"></i>{% trans " Copy" %}</button>
        </form>
    {% endif %}
{% endblock %}
