{% extends "base.html" %}

{% load i18n %}

{% block title %}User Contributed views{% endblock %}
{% block smallheader %}{% endblock %}
{% block largeheader %}User Contributed Views{% endblock %}
{% block toolbar %}{% endblock %}
{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url "contrib.views.index" %}">{% trans "contrib" %}</a>{% endblock %}

{% load adagiostags %}


{% block content %}
    <div class="alert alert-info">
    <p>
        {% blocktrans with dir=settings.contrib_dir %}
	Here you can see a list of user contributed views for
	Adagios. You can make your own from <i>{{ dir }}</i>.
	{% endblocktrans %}
    </p>
    <p>
        {% trans "Please see the examples below for assistance on creating your own custom views." %}
    </p>

    </div>


    <ul>
        {% for i in views %}
            <li><a href="./{{ i }}/">{{ i }}</a></li>
        {% endfor %}
    </ul>
{% endblock %}
