{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "REST Interface" %}{% endblock %}
{% block nav1 %}{% trans "rest" %}{% endblock %}
{% block smallheader %}{% trans "rest" %}{% endblock %}
{% block largeheader %}{{ module_path }}{% endblock %}
{% block toolbar %}{% endblock %}
{% block content %}
        {% if module_documenation %}
            <p>
                {% blocktrans %}The following is the documentation for the {{ module_path }} module:{% endblocktrans %}
            </p>
            <pre class="alert alert-info">{{ module_documenation }}</pre>
        {% else %}
            {% trans "This module has no documentation." %}
        {% endif %}

        <div class=container-fluid>
            <div class=row-fluid>

        <div class=span6>

        {% if gets %}
        <h2>{% trans "Supported GET operations:" %}</h2>
        <table class="table well" >
            {% for i in gets %}
            <tr>
                <td> {{ i }} </td>
                <td><a href="txt/{{ i }}">txt</a></td>
                <td><a href="json/{{ i }}">json</a></td>
                <td><a href="xml/{{ i }}">xml</a></td>
            </tr>
            {% endfor %}
        </table>
        {% endif %}
        </div>

        <div class=span6>
        <h2>{% trans "Supported POST operations" %}</h2>
        <table class="table well">
            {% for i in puts %}
            <tr>
                <td>{{ i }}</td>
                <td><a href="txt/{{ i }}">txt</a></td>
                <td><a href="json/{{ i }}">json</a></td>
                <td><a href="xml/{{ i }}">xml</a></td>
            </tr>
            {% endfor %}
        </table>


        </div>
            </div>
        </div>

{% endblock %}
