{% extends "base_status.html" %}
{% load i18n %}

{% block title %}{% trans "Datatable status" %}{% endblock %}
{% block nav2 %}
{% endblock %}
{% block smallheader %}
{% endblock %}
{% block largeheader %}
    {% trans "Datatable status" %}
{% endblock %}

{% block content %}

<table id="status_dt">
  <thead>
    <tr>
      <th>{% trans "Host name" %}</th>
      <th>{% trans "Service" %}</th>
    </tr>
  </thead>
  <tbody>
  </tbody>
</table>
{% endblock %}

{% block header %} {{ block.super }}
{% endblock %}

{% block footer %}
{{ block.super }}

<script>
$(document).ready(function() {
    $('#status_dt').dataTable( {
        "bProcessing": true,
        "bServerSide": true,

        "sAjaxSource": "/rest/status/json/services_dt"
    } );
} );
</script>

{% endblock %}
