{% extends "base_status.html" %}

{% load i18n %}
{% load static %}

{% block title %}{% trans "Host And Service Overview" %}{% endblock %}
{% block smallheader %}{% endblock %}
{% block largeheader %}{% trans "Host And Service Overview" %}{% endblock %}
{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url "status.views.services" %}">{% trans "Services" %}</a>{% endblock %}
{% load adagiostags %}

{% block sidebar_outer %}
{% endblock %}


{% block content %}
    {% if hosts %}
        {% trans "Hosts:" %}
        {% include "snippets/status_hostlist_snippet.html" %}
    <hr>
    {% else %}
        <p>{% trans "There are no host problems." %}</p>
    {% endif %}
    {% if services %}
        {% trans "Services:" %}
        {% include "snippets/status_servicelist_snippet.html" %}
    {% else %}
        <p>{% trans "There are no service problems." %}</p>
    {% endif %}
{% endblock %}



{% block footer %}
    {{ block.super }}

    <script>
        // Set a reload in X seconds
        adagios.misc.timed_reload({{ user_data.refresh_rate }});
    </script>
{% endblock %}
