<!-- snippet status_hostgrouplist_snippet.html starts -->

{% load adagiostags %}
{% load i18n %}

{% if servicegroups %}
    <table class="table well table-condensed table-striped searchtable"  style="font-size: 80%;" >
        <thead>
            <tr>
                <th>{% trans "Servicegroup" %}</th>
                <th>{% trans "Alias" %}</th>
                <th>{% trans "Number of services" %}</th>
                <th>{% trans "Notes" %}</th>
                <th>{% trans "urls" %}</th>
            </tr>
        </thead>
        <tbody>
        {% for row in servicegroups %}

            <tr class="mainrow">
                <td><a href="{% url 'adagios.status.views.detail' %}?servicegroup_name={{ row.name }}">{{ row.name }}</a></td>
                <td><a href="{% url 'adagios.status.views.detail' %}?servicegroup_name={{ row.name }}">{{ row.alias }}</a></td>
                <td><a href="{% url 'adagios.status.views.detail' %}?servicegroup_name={{ row.name }}">{{ row.num_services }}</a></td>
                <td>{{ row.notes }}</td>
                <td>
                    {% if row.notes_url %}
                        <a href="{{ row.notes_url }}">{% trans "notes" %}</a><
                    {% endif %}
                    {% if row.action_url %}
                        <a href="{{ row.action_url }}">{% trans "action url" %}</a>
                    {% endif %}
            </tr>
        {% endfor %}
            </tbody>
    </table>
{% else %}
{% endif %}
<!-- snippet status_hostgrouplist_snippet.html ends -->
