{% extends "base.html" %}

{% load i18n %}

{% block title %}{% trans "Delete Object" %}{% endblock %}
{% block smallheader %}{% trans "Delete" %}{% endblock %}
{% block largeheader %}{{ object.object_type }}{% endblock %}
{% block toolbar %}{% endblock %}
{% block nav1 %}<a href="{% url "objectbrowser" %}">{% trans "Object Browser" %}</a>{% endblock %}



{% block content %}
    <div class="alert alert-danger">
        {% blocktrans with type=object.object_type desc=object.description file=object.filename %}
	Are you sure you want to delete {{ type }} {{ desc }} from file {{ file }} ?
	{% endblocktrans %}
    </div>
    <form action="#" method="POST" class="form-horizontal">{% csrf_token %}
        {% include "bootstrap_fields.html" with fields=form %}
        <button class="btn btn-danger" type="submit"><i class="icon-trash icon-white"></i> {% trans "Yes, delete it" %}</button>
    </form>
{% endblock %}
