
{% load i18n %}

                    <li class="dropdown">
                        <a class="dropdown-toggle"
                           data-toggle="dropdown"
                           href="#"><i class="glyph-edit glyph-grey"></i> {% trans "myapp is working :)" %}<b class="caret"></b>
                        </a>
                        <ul class="dropdown-menu">
                            <li><a href="{% url "myapp.views.hello_world" %}">{% trans "Click here to see the hello world page" %}</a></li>
                        </ul>
                    </li>
