<!-- snippet status_servicelist_snippet_js.html starts -->
{% load adagiostags %}
{% load i18n %}

<table class="statustable table table-condensed well searchtable" id="datatable">
    <thead>
    <tr>
        <th class="small">
            <div class="btn-group" class="select_bar">
                <a class="" data-toggle="dropdown" href="#">
                    <input type="checkbox" class="select_many">
                </a>
                <ul class="dropdown-menu">
                    <li><a class="select_all"> {% trans "All" %}</a></li>
                    <li><a class="select_none"> {% trans "None" %}</a></li>
                    <li><a class="select_unhandled_problems" > {% trans "Unhandled Problems" %}</a></li>
                    <li><a class="select_problems"> {% trans "All Problems" %}</a></li>
                </ul>
            </div>
        </th>
        <th>{% trans "Host" %}</th>
        <th>{% trans "Service Check" %}</th>
        <td></td>
        <th>{% trans "Duration" %}</th>
        <th>{% trans "Last Check" %}</th>
    </tr>
    </thead>
    <tbody class="">
        <script>
	{% autoescape off %}var services = {{services}};{% endautoescape %}

        </script>
    </tbody>
</table>
<!-- snippet status_servicelist_snippet_js.html ends -->
