{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Business Process" %}{% endblock %}
{% block smallheader %}{% trans "view" %}{% endblock %}
{% block largeheader %}{% trans "Business Process" %}{% endblock %}

{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url "bi.views.index" %}">{% trans "Business Process" %}</a>{% endblock %}

{% load adagiostags %}

{% block content %}
    {% blocktrans %}Are you sure you want to delete {{ bp }} ?{% endblocktrans %}
    <form action="" method="post">{% csrf_token %}
        <button type="submit" class="btn btn-danger">{% trans "Yes, I am sure" %}</button>
    </form>
{% endblock %}



{% block view_buttons %}{% endblock %}
{% block action_buttons %}{% endblock %}
{% block toolbar %}{% endblock %}

