<!--
okconfig_menubar.html is responsible for creating the menuitems in top_navigation_bar of adagios
-->

{% load i18n %}

<li class="dropdown">
    <a class="dropdown-toggle"
       data-toggle="dropdown"
       href="#"><i class="glyph-edit glyph-grey"></i> {% trans "Okconfig" %} <b class="caret"></b>
    </a>
    <ul class="dropdown-menu">
        <li><a href="{% url "okconfig_.views.addhost" %}">{% trans "Add Host" %}</a></li>
        <li><a href="{% url "okconfig_.views.addtemplate" %}">{% trans "Add Template to Host" %}</a></li>
        <li><a href="{% url "okconfig_.views.addservice" %}">{% trans "Add Service" %}</a></li>
        <li><a href="{% url "okconfig_.views.choose_host" %}">{% trans "Edit Host" %}</a></li>
        <li><a href="{% url "okconfig_.views.addgroup" %}">{% trans "Add Group" %}</a></li>
        <li><a href="{% url "okconfig_.views.install_agent" %}">{% trans "Install Agent" %}</a></li>
        <li><a href="{% url "okconfig_.views.scan_network" %}">{% trans "Scan Network" %}</a></li>
    </ul>
</li>
