{% extends "base.html" %}

{% load i18n %}

{% block title %}{% trans "Add Group" %}{% endblock %}
{% block smallheader %}{% trans "Add" %}{% endblock %}
{% block largeheader %}{% trans "Group" %}{% endblock %}
{% block toolbar %}{% endblock %}
{% block nav2 %}<a href="{% url "adagios.okconfig_.views.addgroup" %}">{% trans "Add Group" %}</a>{% endblock %}


{% block content %}
    <form action="#" method="post" class="form-horizontal">{% csrf_token %}
        {% include "bootstrap_fields.html" with fields=form %}
        <div class="form-actions">
            <button class="btn btn-primary" type="submit">{% trans "Submit" %}</button>
        </div>
    </form>
{% endblock %}
