{% extends "base.html" %}
{% load i18n %}
{% load cycle from future %}

{% block title %}{% trans "Edit Host" %}{% endblock %}
{% block smallheader %}{% trans "Edit" %}{% endblock %}
{% block largeheader %}{% trans "Host" %}{% endblock %}
{% block toolbar %}{% endblock %}
{% block content %}
{% if okconfig_checks %}


<div>
	<table>
	 <thead><tr>
	  <th>{% trans "Check" %}</th>
	  <th>{% trans "Result" %}</th>
	 </tr></thead>
	 <tbody>
		{% for check,value in okconfig_checks.items %}
		<tr class="{% cycle "even" "odd" %}">
	  		<td>{{ check }}</td>
	  		<td>{{ value }}</td>
		</tr>
		{% endfor %}
	 </tbody></table>
</div>
{% endif %}


{% endblock %}
