{% extends "base.html" %}

{% load i18n %}

{% block title %}{% trans "REST Interface" %}{% endblock %}
{% block nav1 %}{% trans "rest" %}{% endblock %}
{% block smallheader %}{% trans "rest" %}{% endblock %}
{% block largeheader %}{{ module_path }}{% endblock %}
{% block sidebar %}{% endblock %}
{% block toolbar %}{% endblock %}
{% block content %}
    {% if rest_modules %}
        <div class="alert alert-info">{% trans "The following rest modules have been loaded:" %}</div>
        <ul>
            {% for k, v in rest_modules.items %}
            <li>
                <a href="{% url "rest.views.list_modules" %}/{{ k }}">{{ k }}</a></li>
            {% endfor %}
        </ul>
    {% endif %}
{% endblock %}
