{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Servicegroups" %}{% endblock %}

{% block nav2 %}
    <a href="{% url 'status.views.status_servicegroups' %}">{% trans "Servicegroups" %}</a>
{% endblock %}
{% block smallheader %}{% endblock %}

{% block largeheader %}{% trans "Servicegroups" %}{% endblock %}

{% block content %}
    {% include "snippets/status_servicegrouplist_snippet.html" %}
{% endblock %}



{% block view_buttons %}{% endblock %}
{% block action_buttons %}{% endblock %}
