{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Comments" %}{% endblock %}
{% block smallheader %}{% endblock %}
{% block largeheader %}{% trans "Comments" %}{% endblock %}

{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url 'status.views.comment_list' %}">{% trans "Comments" %}</a>{% endblock %}

{% load adagiostags %}

{% block content %}
    <ul class="nav nav-tabs" id="objecttab">
        <li class="active"><a href="{% url 'adagios.status.views.comment_list' %}" >{% trans "Comments" %}</a></li>
        <li><a href="{% url 'adagios.status.views.downtime_list' %}">{% trans "Downtimes" %}</a></li>
        <li><a href="{% url 'adagios.status.views.acknowledgement_list' %}">{% trans "Acknowledgements" %}</a></li>
    </ul>
    <div class="tab-content">

        <div class="tab-pane active" id="comments">
            {% include "snippets/status_commentlist_snippet.html" %}
        </div>

    </div>

{% endblock %}

{% block view_buttons %}{% endblock %}
{% block action_buttons %}{% endblock %}

{% block footer %} {{ block.super }} {% endblock %}
