{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Monitor" %}{% endblock %}
{% block page_content %}


<iframe style="position: absolute;top: 40px; left: 0px" src="{{ nagios_url }}" width="100%" height="100%" >
{% blocktrans %}This iframe is supposed to display nagios url at {{ nagios_url }}{% endblocktrans %}
</iframe>

{% endblock %}
