<!-- snippet status_contactgrouplist_snippet.html starts -->

{% load i18n %}

<table style="font-size: 80%;" class="table well table-condensed table-striped searchtable">
    <thead>
    <th>{% trans "Group Name" %}</th>
    <th>{% trans "Alias" %}</th>
    <th>{% trans "Members" %}</th>
    </thead>
    {% for i in contactgroups  %}
        <tr class="mainrow">
            <td><a href="{% url 'adagios.status.views.services' %}?contact_groups__has_field={{ i.name }}">{{ i.name }}</a></td>
            <td>{{ i.alias }}</td>
            <td>
                {% for x in i.members %}
                <a href="{% url 'status.views.detail' %}?contact_name={{ x }}">{{ x }}</a>,
                {% endfor %}
            </td>
        </tr>
    {% endfor %}
</table>
<!-- snippet status_contactgrouplist_snippet.html ends -->
