{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Status Overview" %}{% endblock %}
{% block smallheader %}{% endblock %}
{% block largeheader %}{% trans "Service Overview" %}{% endblock %}
{% block nav1 %}{{ block.super }}{% endblock %}
{% block nav2 %}<a href="{% url 'status.views.services' %}">{% trans "Services" %}</a>{% endblock %}
{% load adagiostags %}

{% block sidebar_outer %}
{% endblock %}

{% block content %}
    {% include "snippets/status_servicelist_snippet.html" %}
{% endblock %}



{% block footer %}
    {{ block.super }}

    <script>
        // Set a reload in X seconds
        adagios.misc.timed_reload({{ user_data.refresh_rate }});
    </script>
{% endblock %}
