{% extends "base_status.html" %}

{% load i18n %}

{% block title %}{% trans "Hostgroups" %}{% endblock %}
{% block nav2 %}
    <a href="{% url 'status.views.status_hostgroups' %}">{% trans "Hostgroups" %}</a>
    {% if hostgroup_name %}
    / {{ hostgroup_name }}
    {% else %}
    {% endif %}
{% endblock %}
{% block smallheader %}
    {% if hostgroup_name %}{% trans "hostgroup" %}
    {% endif %}
{% endblock %}
{% block largeheader %}
    {% if hostgroup_name %}{{ hostgroup_name }}
    {% else %}
    {% trans "Hostgroups" %}
    {% endif %}
{% endblock %}

{% block view_buttons %}{% endblock %}

{% block content %}
    {% include "snippets/status_hostgrouplist_snippet.html" %}
{% endblock %}

{% block header %} {{ block.super }}
{% endblock %}



{% block footer %} {{ block.super }} <style>
    .input-append button.add-on {
        height: inherit !important;
    }
</style> {% endblock %}


